@@ -1,9 +1,15 @@
+from dependency_injector.wiring import Provide, inject
+from sanic import Request
+
+
 async def some_handler(request):
-    pass
+    return {}
 
 
-async def some_protect(*asfasgasg, **kwargs):
-    pass
+@inject
+async def some_protect(request: Request, app_container=Provide["<container>"]):
+    print(app_container)
+    return None
 
 
 class SomeDto:
@@ -30,8 +36,6 @@ routes_dict = {
                     "post": {
                         "handler": some_handler,
                         "protector": some_protect,
-                        "in_dto": SomeDto,
-                        "out_dto": SomeDto2,
                     }
                 },
                 "/ticketsssswss": {
